@@ -18,26 +18,26 @@
 # along with pspman.  If not, see <https://www.gnu.org/licenses/>.
 #
 '''
-PSPMAN: **PS**\ eudo **P**\ ackage **Man**\ ager
+PSPMAN: PSeudo Package Manager
 
 '''
 
-
 # Globally defined environment configuration
 from pathlib import Path
+
 from psprint import init_print
-from .classes import InstallEnv
-from .config import read_config
 
+from pspman.classes import InstallEnv
+from pspman.config import read_config
 
-print = init_print(Path(__file__).resolve()
-                   .parent.joinpath(".psprintrc.yml")).psprint
+# Type: PathLike To be fixed in psprint
+print = init_print(Path(__file__).resolve().parent.joinpath(
+    ".psprintrc.yml")).psprint  # type: ignore
 '''
 Customized psprint function
 
 '''
 
-
 # ConfigBase
 CONFIG = read_config()
 '''
@@ -50,5 +50,4 @@ ENV = InstallEnv(CONFIG)
 Standard installation context
 '''
 
-
-__version__ = '1!1.3.0'
+__version__ = '1!1.5.1'
