@@ -30,9 +30,9 @@ from pathlib import Path
 import json
 import yaml
 from psprint import print
-from .config import MetaConfig
-from .tag import ACTION_TAG
-from .errors import GitURLError
+from pspman.config import MetaConfig
+from pspman.tag import ACTION_TAG
+from pspman.errors import GitURLError
 
 
 class InstallEnv():
@@ -64,6 +64,7 @@ class InstallEnv():
         self.pull: bool = kwargs.get('pull', False)
         self.stale: bool = kwargs.get('stale', False)
         self.verbose: bool = kwargs.get('verbose', False)
+        self.reset: typing.List[str] = kwargs.get('reset', [])
         self.install: typing.List[str] = kwargs.get('install', [])
         self.delete: typing.List[str] =  kwargs.get('delete', [])
 
@@ -95,6 +96,7 @@ class InstallEnv():
         Prefix: {self.prefix}
 
         Called sub-function: {self.call_function}
+        Clean-Resets Requested: {len(self.reset)}
         Deletions Requested: {len(self.delete)}
         Additions requested: {len(self.install)}
 
