@@ -22,20 +22,47 @@ Define variables from command line and defaults
 
 '''
 
-
-import os
-import sys
-import typing
-import subprocess
-from pathlib import Path
 import argparse
+import os
 import shutil
+from pathlib import Path
+from typing import Any, Dict, List, Union
+
 import argcomplete
+import yaml
 from psprint import print
-from . import CONFIG
-from .config import MetaConfig
-from .classes import InstallEnv
-from .tools import timeout
+from xdgpspconf import utils
+
+from pspman import CONFIG
+from pspman.classes import InstallEnv
+from pspman.config import MetaConfig
+from pspman.tools import timeout
+
+
+def parse_install_yml(inyaml: Path = None) -> List[str]:
+    """
+    Parse input file to extract installation urls
+
+    Args:
+        inyaml: path to installation input file
+
+    Returns:
+        Extracted installation list
+    """
+    if inyaml is None:
+        return []
+    with open(inyaml) as install_h:
+        _install_urls: Union[str, List[str],
+                             Dict[str, str]] = yaml.safe_load(install_h)
+    install_urls: List[str] = []
+    for gitline in _install_urls:
+        if isinstance(gitline, str):
+            install_urls.append(gitline)
+        elif isinstance(gitline, dict):
+            install_urls.append(*gitline.values())
+        elif isinstance(gitline, list):
+            install_urls.append(*gitline)  # type: ignore
+    return install_urls
 
 
 def cli(config: MetaConfig = None) -> argparse.ArgumentParser:
@@ -54,72 +81,92 @@ def cli(config: MetaConfig = None) -> argparse.ArgumentParser:
 
     \033[1;91mNOTICE: This is only intended for "user" packages.
     CAUTION: DO NOT RUN THIS SCRIPT AS ROOT.
-    CAUTION: If you still insist, I won't care.\033[0m
+    CAUTION: If you still insist, I won't care.\033[m
     '''
 
-
     d_pref = config.data_dir
     parser = argparse.ArgumentParser(
-        description=description,
-        formatter_class=argparse.RawTextHelpFormatter
-    )
-    sub_parsers = parser.add_subparsers()
-    version = sub_parsers.add_parser(name='version', aliases=['ver'],
-                                     help='display version and exit')
-    unlock = sub_parsers.add_parser(name='unlock', aliases=[],
-                                    help='Unlock C_DIR and exit')
+        description=description, formatter_class=argparse.RawTextHelpFormatter)
 
-    list_gits = sub_parsers.add_parser(
-        name='list', aliases=['info'],
-        help='display list of cloned repositories and exit'
-    )
-    list_gits.add_argument('--meta', '-m', action='store_true',
-                           help='List known C_DIR(s)')
-
-    init = sub_parsers.add_parser(name='init', aliases=['initialize'],
-                                  help='initialize pspman')
-    init.add_argument('--ignore', '-i', type=str, metavar='DEP', nargs='*',
-                      help='initialize without dependency DEP')
-
-    goodbye = sub_parsers.add_parser(name='goodbye', aliases=['de-initialize'],
-                                     help='Cleanup before uninstalling pspman')
-
-    init.set_defaults(call_function='init')
-    goodbye.set_defaults(call_function='goodbye')
-    version.set_defaults(call_function='version')
-    unlock.set_defaults(call_function='unlock')
-    list_gits.set_defaults(call_function='info')
-    parser.set_defaults(call_function=None)
-    parser.add_argument('--init', action='store_true',
+    # base arguments
+    parser.add_argument('--init',
+                        action='store_true',
                         help='Initialize PSPMan')
-    parser.add_argument('--version', action='store_true',
+    parser.add_argument('--version',
+                        action='store_true',
                         help='Display version and exit')
-    parser.add_argument('-l', '--list', action='store_true', dest='info',
+    parser.add_argument('-l',
+                        '--list',
+                        action='store_true',
+                        dest='info',
                         help='display list of cloned repositories and exit')
-    parser.add_argument('-v', '--verbose', action='store_true',
+    parser.add_argument('-v',
+                        '--verbose',
+                        action='store_true',
                         help='display verbose output')
-    parser.add_argument('-s', '--stale', action='store_true',
+    parser.add_argument('-s',
+                        '--stale',
+                        action='store_true',
                         help='skip updates, let repositories remain stale')
-    parser.add_argument('-o', '--only-pull', action='store_true', dest='pull',
+    parser.add_argument('-o',
+                        '--only-pull',
+                        action='store_true',
+                        dest='pull',
                         help='only pull, do not try to install')
-    parser.add_argument('-f', '--force-risk', action='store_true', dest='risk',
+    parser.add_argument('-f',
+                        '--force-risk',
+                        action='store_true',
+                        dest='risk',
                         help='force working with root permissions [DANGEROUS]')
-    parser.add_argument('-p', '--prefix', type=str, nargs='?', metavar='PREF',
+    parser.add_argument('-p',
+                        '--prefix',
+                        type=Path,
+                        nargs='?',
+                        metavar='PREF',
                         help=f'path for installation [default: {d_pref}]',
                         default=d_pref)
-    parser.add_argument('-c', '--clone-dir', type=str, nargs='?', default=None,
-                        metavar='C_DIR', help=f'''Clone git repos in C_DIR.
+    parser.add_argument('-c',
+                        '--clone-dir',
+                        type=Path,
+                        nargs='?',
+                        default=None,
+                        metavar='C_DIR',
+                        help=f'''Clone git repos in C_DIR.
 Please check if you want to add this to PATH.
 [default: PREF{os.sep}src]
 ''')
-    parser.add_argument('-d', '--delete', metavar='PROJ', type=str, nargs='*',
-                        default=[], help='delete PROJ')
-    parser.add_argument('-i', '--install', metavar='URL', type=str, nargs='*',
+    parser.add_argument('-r',
+                        '--reset',
+                        metavar='PROJ',
+                        type=str,
+                        nargs='*',
                         default=[],
-        help=f'''
+                        help='clean-reset PROJ code')
+    parser.add_argument('-d',
+                        '--delete',
+                        metavar='PROJ',
+                        type=str,
+                        nargs='*',
+                        default=[],
+                        help='delete PROJ')
+    parser.add_argument('-I',
+                        '--install-from',
+                        metavar='YML',
+                        type=Path,
+                        nargs='?',
+                        default=None,
+                        dest='inyaml',
+                        help='Install packages from a yaml file')
+    parser.add_argument('-i',
+                        '--install',
+                        metavar='URL',
+                        type=str,
+                        nargs='*',
+                        default=[],
+                        help=f'''
 format: "URL[___branch[___'only'|___inst_argv[___sh_env]]]"
 
-* *REMEMBER the QUOTATION MARKS*
+* *REMEMBER QUOTATION MARKS*
 
 * URL: url to be cloned.
 * branch: custom branch to clone. Blank implies default.
@@ -128,10 +175,69 @@ format: "URL[___branch[___'only'|___inst_argv[___sh_env]]]"
 * sh_env: VAR1=VAL1,VAR2=VAL2,VAR3=VAL3.... Modified install environment.
 
 ''')
+    parser.set_defaults(call_function=None)
+
+    # sub-commands
+    sub_parsers = parser.add_subparsers()
+
+    version = sub_parsers.add_parser(name='version',
+                                     aliases=['ver'],
+                                     help='display version and exit')
+    version.set_defaults(call_function='version')
+
+    switch = sub_parsers.add_parser(
+        name='switch',
+        aliases=['activate', 'export'],
+        help='switch to environment temporarily\n' +
+        'with additional *PATH variables from PREFIX')
+    switch.add_argument('switch_to',
+                        type=str,
+                        metavar='GIT_GROUP|PATH',
+                        help="GIT_GROUP's name or path",
+                        nargs='?',
+                        default='default')
+    switch.add_argument('-c',
+                        '--copy',
+                        action='store_true',
+                        dest='clipboard',
+                        help='try to copy soruce command to clipboard')
+    switch.set_defaults(call_function='switch')
+
+    unlock = sub_parsers.add_parser(name='unlock',
+                                    aliases=[],
+                                    help='Unlock C_DIR and exit')
+    unlock.set_defaults(call_function='unlock')
+
+    list_gits = sub_parsers.add_parser(
+        name='list',
+        aliases=['info'],
+        help='display list of cloned repositories and exit')
+    list_gits.add_argument('--meta',
+                           '-m',
+                           action='store_true',
+                           help='List known C_DIR(s)')
+    list_gits.set_defaults(call_function='info')
+
+    init = sub_parsers.add_parser(name='init',
+                                  aliases=['initialize'],
+                                  help='initialize pspman')
+    init.add_argument('--ignore',
+                      '-i',
+                      type=str,
+                      metavar='DEP',
+                      nargs='*',
+                      help='initialize without dependency DEP')
+    init.set_defaults(call_function='init')
+
+    goodbye = sub_parsers.add_parser(name='goodbye',
+                                     aliases=['de-initialize'],
+                                     help='Cleanup before uninstalling pspman')
+    goodbye.set_defaults(call_function='goodbye')
+
     return parser
 
 
-def cli_opts(config: MetaConfig = None) -> typing.Dict[str, typing.Any]:
+def cli_opts(config: MetaConfig = None) -> Dict[str, Any]:
     '''
     Parse cli arguments to return its dict
     '''
@@ -150,7 +256,9 @@ def cli_opts(config: MetaConfig = None) -> typing.Dict[str, typing.Any]:
         setattr(args, 'call_function', 'version')
     if args.init:
         setattr(args, 'call_function', 'init')
-    return vars(args)
+    cli_args = vars(args)
+    cli_args['install'].extend(parse_install_yml(cli_args['inyaml']))
+    return cli_args
 
 
 def perm_pass(env: InstallEnv, permdir: Path) -> int:
@@ -164,43 +272,12 @@ def perm_pass(env: InstallEnv, permdir: Path) -> int:
     '''
     if env.verbose:
         print(f'Checking permissions for {permdir}')
-    while not permdir.exists():
-        # clone/prefix directory get be created anew
-        permdir = permdir.resolve().parent
-        if env.verbose:
-            print(f'Checking permissions for the parent: {permdir}')
     user = os.environ.get('USER', 'root')
-    stdout, err = subprocess.Popen(['stat', '-L', '-c', "%U %G %a", permdir],
-                                   text=True, stdout=subprocess.PIPE,
-                                   stderr=subprocess.PIPE).communicate()
-    if err:
-        print('Error checking directory permissions, aborting...', mark=5)
-        return 1
-    owner, group, octperm = stdout.replace("\n", '').split(' ')
-    if (octperm[-1] == '7') != 0:
-        # everyone has access
+    access = utils.fs_perm(path=permdir, mode='rwx')
+    if access:
         return 0
-    if (octperm[-2] == '7') != 0:
-        # some group has permissions
-        stdout, err = subprocess.Popen(['groups', user], text=True,
-                                       stdout=subprocess.PIPE,
-                                       stderr=subprocess.PIPE).communicate()
-        if err:
-            # error
-            print('Error checking group permissions, aborting...', mark=5)
-            return 1
-        user_groups = stdout.split(' ')
-        for u_grp in user_groups:
-            if u_grp == group:
-                return 0
-    if (octperm[-3] == '7') != 0:
-        # owner has permissions
-        if user == owner:
-            return 0
-    print(f'''
-    We [{user}] do not have sufficient permissions [{octperm}]
-    on {owner}'s directory: {permdir}
-    ''', mark=5)
+    print(f'We [{user}] do not have sufficient permissions on {permdir}',
+          mark=5)
     print('Try another location', mark=2)
     return 1
 
@@ -218,8 +295,7 @@ def prepare_env(env: InstallEnv) -> int:
         if not env.risk:
             print('Bye', mark=0)
             return 2
-        print('I can only hope you know what you are doing...',
-              mark=3)
+        print('I can only hope you know what you are doing...', mark=3)
         print('Here is a chance to kill me in', mark=2)
         try:
             timeout(10)
@@ -227,8 +303,11 @@ def prepare_env(env: InstallEnv) -> int:
             print("Aborting.", pref_color='g', pref=chr(0x1f197), short=False)
             return 1
         print()
-        print("Your decision", pref=chr(0x1f937), pref_color='r',
-              text_color="y", short=False)
+        print("Your decision",
+              pref=chr(0x1f937),
+              pref_color='r',
+              text_color="y",
+              short=False)
         print()
         print('Proceeding...', mark=1)
     else:
@@ -243,19 +322,20 @@ def prepare_env(env: InstallEnv) -> int:
     return 0
 
 
-def lock(env: InstallEnv, unlock: bool = False):
+def lock(env: InstallEnv, unlock: bool = False, message: str = None):
     '''
     Unlock up the directory
 
     Args:
         env: installation context
         unlock: unlock existing locks?
+        message: message to be written in the lockfile instead of pid
 
     Returns:
         Error code
 
     '''
-    lock_path = env.clone_dir.joinpath('.proc.lock')
+    lock_path = env.prefix.joinpath('.proc.lock')
     # lockfile is deliberately human-readable
 
     if lock_path.exists():
@@ -273,16 +353,16 @@ def lock(env: InstallEnv, unlock: bool = False):
             lock_path.unlink()
             return 1
         with open(lock_path, 'r') as lock_fh:
-            print(f"Process with id {lock_fh.read()} is incomplete...",
+            print(f"This git-group was locked for safety by {lock_fh.read()}",
                   mark='err')
         print("Either wait for the process to get completed")
         print("OR interrupt the process and execute")
-        print(f"pspman -c {env.clone_dir.parent} unlock", mark='act')
-        print("This WILL generally MESS UP source codes.", mark='warn')
+        print(f"pspman -p {env.prefix} unlock", mark='act')
+        print("Interruption WILL generally MESS UP source codes.", mark='warn')
         return 2
     if unlock:
         print(f'Lockfile {lock_path} not found.')
         return 2
     with open(lock_path, 'w') as lock_fh:
-        lock_fh.write(str(os.getpid()))
+        lock_fh.write(str(message) or 'pid:' + str(os.getpid()))
     return 0
