@@ -37,20 +37,20 @@ All `actions` accept same set of args and return same type of object
 
 '''
 
-
-import typing
 import shutil
+import typing
 from pathlib import Path
-from . import print, CONFIG
-from .shell import git_clean, git_pull, git_clone
-from .classes import InstallEnv, GitProject
-from .tag import ACTION_TAG, FAIL_TAG, TAG_ACTION, RET_CODE
-from .installations import INST_METHODS, run_install
+
+from pspman import CONFIG, print
+from pspman.classes import GitProject, InstallEnv
+from pspman.installations import INST_METHODS, run_install
+from pspman.shell import git_clean, git_clone, git_pull
+from pspman.tag import ACTION_TAG, FAIL_TAG, RET_CODE, TAG_ACTION
 
 
 def delete(
-        args: typing.Tuple[InstallEnv, GitProject]
-) -> typing.Tuple[str, int, int]:
+        args: typing.Tuple[InstallEnv,
+                           GitProject]) -> typing.Tuple[str, int, int]:
     '''
     Delete this project
 
@@ -69,26 +69,30 @@ def delete(
 
     This project may be added again using:
     pspman -i {project.url}
-    ''', mark='delete' )
+    ''',
+          mark='delete')
     # Attempt uninstallation
-    code_path = Path(env.clone_dir).joinpath(project.name)
+    code_path = Path(env.clone_dir) / project.name
     i_type = None
     for method_name, method in INST_METHODS.items():
-        if (any(code_path.joinpath(id_file).exists()
-                for id_file in method.instruct.indicate) and not
-            any(code_path.joinpath(xd_file).exists()
-                for xd_file in method.instruct.exdicate)):
+        if (any((code_path / id_file).exists()
+                for id_file in method.instruct.indicate) and not any(
+                    (code_path / xd_file).exists()
+                    for xd_file in method.instruct.exdicate)):
             i_type = method_name
             break
     if i_type is not None:
         # Known uninstallation method
         if env.verbose:
-            print( f'''
+            print(f'''
             Trying standard uninstall calls with {i_type}.
             This may not always be clean; some scars may stay back.
-            ''', mark='delete')
-        success = run_install(i_type='u_' + i_type, code_path=code_path,
-                              prefix=env.prefix, argv=project.inst_argv,
+            ''',
+                  mark='delete')
+        success = run_install(i_type='u_' + i_type,
+                              code_path=code_path,
+                              prefix=env.prefix,
+                              argv=project.inst_argv,
                               env=project.sh_env)
         if not success:
             if env.verbose:
@@ -104,7 +108,7 @@ def delete(
     if env.verbose:
         print('Erasing source code', mark='delete')
     try:
-        shutil.rmtree(Path(env.clone_dir).joinpath(project.name))
+        shutil.rmtree(Path(env.clone_dir) / project.name)
         return project.name, project.tag & (0xff - ACTION_TAG['delete']),\
             RET_CODE['pass']
     except OSError:
@@ -113,8 +117,8 @@ def delete(
 
 
 def clone(
-        args: typing.Tuple[InstallEnv, GitProject]
-) -> typing.Tuple[str, int, int]:
+        args: typing.Tuple[InstallEnv,
+                           GitProject]) -> typing.Tuple[str, int, int]:
     '''
     Get (clone) the remote project.url
 
@@ -134,8 +138,10 @@ def clone(
     gitkwargs: typing.Dict[str, typing.Optional[str]] = {}
     if project.branch is not None:
         gitkwargs['branch'] = project.branch
-    ret = git_clone(clone_dir=Path(env.clone_dir).joinpath(project.name),
-                    url=project.url, name=project.name, gitkwargs=gitkwargs)
+    ret = git_clone(clone_dir=Path(env.clone_dir) / project.name,
+                    url=project.url,
+                    name=project.name,
+                    gitkwargs=gitkwargs)
     if ret is None:
         # STDERR thrown
         print(f'Failed to clone source of {project.name}', mark='fclone')
@@ -147,8 +153,8 @@ def clone(
 
 
 def update(
-        args: typing.Tuple[InstallEnv, GitProject]
-) -> typing.Tuple[str, int, int]:
+        args: typing.Tuple[InstallEnv,
+                           GitProject]) -> typing.Tuple[str, int, int]:
     '''
     Update (pull) source code.
 
@@ -162,8 +168,7 @@ def update(
 
     '''
     env, project = args
-    code_path = Path(env.clone_dir).joinpath(project.name)
-    git_clean(code_path)
+    code_path = Path(env.clone_dir) / project.name
     g_pull = git_pull(clone_dir=code_path)
     if g_pull is not None:
         # STDERR from pull was blank
@@ -184,8 +189,8 @@ def update(
 
 
 def install(
-        args: typing.Tuple[InstallEnv, GitProject]
-) -> typing.Tuple[str, int, int]:
+        args: typing.Tuple[InstallEnv,
+                           GitProject]) -> typing.Tuple[str, int, int]:
     '''
     Install (update) from source code.
 
@@ -203,18 +208,20 @@ def install(
         if env.verbose:
             print(f'Not trying to install {project.name}', mark='bug')
         return project.name, tag, RET_CODE['asis']
-    code_path = Path(env.clone_dir).joinpath(project.name)
+    code_path = Path(env.clone_dir) / project.name
     i_type = None
     for method_name, method in INST_METHODS.items():
-        if (any(code_path.joinpath(id_file).exists()
-                for id_file in method.instruct.indicate) and not
-            any(code_path.joinpath(xd_file).exists()
-                for xd_file in method.instruct.exdicate)):
+        if (any((code_path / id_file).exists()
+                for id_file in method.instruct.indicate) and not any(
+                    (code_path / xd_file).exists()
+                    for xd_file in method.instruct.exdicate)):
             i_type = method_name
             break
     if i_type is not None:
-        success = run_install(i_type=i_type, code_path=code_path,
-                              prefix=env.prefix, argv=project.inst_argv,
+        success = run_install(i_type=i_type,
+                              code_path=code_path,
+                              prefix=env.prefix,
+                              argv=project.inst_argv,
                               env=project.sh_env)
         if success:
             if env.verbose:
@@ -226,14 +233,14 @@ def install(
     if env.verbose:
         print(f'FAILED Installing (update for) project {project.name}',
               mark='finstall')
-        if TAG_ACTION[project.tag&0xf0] not in CONFIG.opt_in:
+        if TAG_ACTION[project.tag & 0xf0] not in CONFIG.opt_in:
             print(f'PSPMan was initialized only with {CONFIG.opt_in}')
     git_clean(code_path)
     return project.name, project.tag, RET_CODE['fail']
 
 
 def success(
-        args: typing.Tuple[InstallEnv, typing.Optional[GitProject]]
+    args: typing.Tuple[InstallEnv, typing.Optional[GitProject]]
 ) -> typing.Tuple[str, int, int]:
     '''
     List successful projects
@@ -247,7 +254,7 @@ def success(
         project.name, project.tag, ``RET_CODE``[``pass``]
 
     '''
-    env, project = args
+    _, project = args
     if project is None:
         return 'None', 0x00, RET_CODE['asis']
     project.mark_update_time()
@@ -256,8 +263,8 @@ def success(
 
 
 def failure(
-        args: typing.Tuple[InstallEnv, GitProject]
-) -> typing.Tuple[str, int, int]:
+        args: typing.Tuple[InstallEnv,
+                           GitProject]) -> typing.Tuple[str, int, int]:
     '''
     List failure points in projects
 
